"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
require("./module");
const process_1 = __importDefault(require("process"));
const preset_env_1 = __importDefault(require("@babel/preset-env"));
const preset_react_1 = __importDefault(require("@babel/preset-react"));
const babel_plugin_commonjs_1 = __importDefault(require("@mo36924/babel-plugin-commonjs"));
const babel_plugin_dead_code_elimination_1 = __importDefault(require("@mo36924/babel-plugin-dead-code-elimination"));
const babel_plugin_iife_unwrap_1 = __importDefault(require("@mo36924/babel-plugin-iife-unwrap"));
const babel_plugin_inject_1 = __importDefault(require("@mo36924/babel-plugin-inject"));
const babel_plugin_replace_1 = __importDefault(require("@mo36924/babel-plugin-replace"));
const babel_plugin_replace_import_extensions_1 = __importDefault(require("@mo36924/babel-plugin-replace-import-extensions"));
const babel_plugin_resolve_1 = __importDefault(require("@mo36924/babel-plugin-resolve"));
const { NODE_ENV, NODE_TARGET } = process_1.default.env;
exports.default = (api, options) => {
    const { env: __ENV__ = NODE_ENV ?? "production", target: __TARGET__ = NODE_TARGET ?? "node", jsx = "react", inject: _inject = {}, extensions: _extensions = {}, namedExports = {}, } = options;
    const __PROD__ = __ENV__ === "production" || undefined;
    const __DEV__ = __ENV__ === "development" || undefined;
    const __TEST__ = __ENV__ === "test" || undefined;
    const __NODE__ = __TARGET__ === "node" || undefined;
    const __BROWSER__ = !__NODE__ || undefined;
    const __MODULE__ = __TARGET__ === "module" || undefined;
    const __NOMODULE__ = __TARGET__ === "nomodule" || undefined;
    if (jsx === "react") {
        for (const mod of [
            "react",
            "react-dom",
            "react-dom/server",
            "react-dom/server.browser",
            "react/jsx-runtime",
            "react/jsx-dev-runtime",
        ]) {
            try {
                // eslint-disable-next-line import/no-dynamic-require
                namedExports[mod] = Object.keys(require(mod));
            }
            catch { }
        }
    }
    return {
        presets: [
            [
                preset_env_1.default,
                {
                    bugfixes: true,
                    modules: false,
                    loose: false,
                    ignoreBrowserslistConfig: true,
                    targets: __NODE__
                        ? {
                            node: true,
                        }
                        : __MODULE__
                            ? {
                                esmodules: true,
                            }
                            : {
                                android: "4.4",
                                chrome: "41",
                                edge: "16",
                                firefox: "60",
                                ie: "11",
                                ios: "10.3",
                                opera: "48",
                                safari: "10.1",
                                samsung: "8.2",
                            },
                    useBuiltIns: false,
                    debug: __DEV__,
                },
            ],
            [
                preset_react_1.default,
                {
                    runtime: "automatic",
                    development: __DEV__,
                    importSource: jsx,
                },
            ],
        ],
        plugins: [
            [
                babel_plugin_replace_1.default,
                {
                    "typeof self": __NODE__ ? "'undefined'" : "'object'",
                    "typeof global": __NODE__ ? "'object'" : "'undefined'",
                    "typeof process": "'object'",
                    "process.env.NODE_ENV": `'${__ENV__}'`,
                    __ENV__: `'${__ENV__}'`,
                    __TARGET__: `'${__TARGET__}'`,
                    __PROD__: `${__PROD__}`,
                    __DEV__: `${__DEV__}`,
                    __TEST__: `${__TEST__}`,
                    __NODE__: `${__NODE__}`,
                    __BROWSER__: `${__BROWSER__}`,
                    __MODULE__: `${__MODULE__}`,
                    __NOMODULE__: `${__NOMODULE__}`,
                    ...(__MODULE__ ? { "typeof Event": "'function'" } : {}),
                },
            ],
            [babel_plugin_dead_code_elimination_1.default],
            [babel_plugin_iife_unwrap_1.default],
            [
                babel_plugin_resolve_1.default,
                {
                    ignoreBuiltins: __NODE__,
                    aliasFields: __NODE__ ? [] : ["browser"],
                    mainFields: __NODE__ ? ["module", "main"] : ["browser", "module", "main"],
                    conditionNames: __NODE__ ? ["import"] : ["browser", "import"],
                    extensions: __NODE__
                        ? [
                            ".server.tsx",
                            ".server.ts",
                            ".server.jsx",
                            ".server.mjs",
                            ".server.js",
                            ".server.json",
                            ".tsx",
                            ".ts",
                            ".jsx",
                            ".mjs",
                            ".js",
                            ".json",
                        ]
                        : [
                            ".client.tsx",
                            ".client.ts",
                            ".client.jsx",
                            ".client.mjs",
                            ".client.js",
                            ".client.json",
                            ".tsx",
                            ".ts",
                            ".jsx",
                            ".mjs",
                            ".js",
                            ".json",
                        ],
                    ignore: [/^\0/],
                },
            ],
            [babel_plugin_replace_import_extensions_1.default, _extensions],
            [babel_plugin_commonjs_1.default, __NODE__ ? namedExports : false],
            [babel_plugin_inject_1.default, _inject],
        ],
    };
};
//# sourceMappingURL=index.js.map